@@ -251,8 +251,8 @@ export async function connectWithMaxRetries(
 export function findFreeTcpPort(): Promise<number> {
   return new Promise((resolve) => {
     const srv = net.createServer();
-    // $FLOW_FIXME: flow has his own opinions on this method signature.
-    srv.listen(0, () => {
+    // $FLOW_FIXME: signature for listen() is missing - see https://github.com/facebook/flow/pull/8290
+    srv.listen(0, '127.0.0.1', () => {
       const freeTcpPort = srv.address().port;
       srv.close(() => resolve(freeTcpPort));
     });
