@@ -4,8 +4,10 @@ import path from 'path';
 import {readFileSync} from 'fs';
 
 import camelCase from 'camelcase';
+import decamelize from 'decamelize';
 import git from 'git-rev-sync';
 import yargs from 'yargs';
+import { Parser as yargsParser } from 'yargs/yargs';
 
 import defaultCommands from './cmd';
 import {UsageError} from './errors';
@@ -53,6 +55,7 @@ export class Program {
   shouldExitProgram: boolean;
   verboseEnabled: boolean;
   options: Object;
+  programArgv: Array<string>;
 
   constructor(
     argv: ?Array<string>,
@@ -65,6 +68,7 @@ export class Program {
     // NOTE: process.argv.slice(2) removes the path to node and web-ext
     // executables from the process.argv array.
     argv = argv || process.argv.slice(2);
+    this.programArgv = argv;
 
     // NOTE: always initialize yargs explicitly with the package dir
     // to avoid side-effects due to yargs looking for its configuration
@@ -174,6 +178,31 @@ export class Program {
     return argv;
   }
 
+  // Remove WEB_EXT_* environment vars that are not a global cli options
+  // or an option supported by the current command (See #793).
+  cleanupProcessEnvConfigs(systemProcess: typeof process) {
+    const cmd = yargsParser(this.programArgv)._[0];
+    const env = systemProcess.env || {};
+    const toOptionKey = (k) => decamelize(
+      camelCase(k.replace(envPrefix, '')), '-'
+    );
+
+    if (cmd) {
+      Object.keys(env)
+        .filter((k) => k.startsWith(envPrefix))
+        .forEach((k) => {
+          const optKey = toOptionKey(k);
+          const globalOpt = this.options[optKey];
+          const cmdOpt = this.options[cmd] && this.options[cmd][optKey];
+
+          if (!globalOpt && !cmdOpt) {
+            log.debug(`Environment ${k} not supported by web-ext ${cmd}`);
+            delete env[k];
+          }
+        });
+    }
+  }
+
   async execute(
     {
       checkForUpdates = defaultUpdateChecker,
@@ -190,6 +219,7 @@ export class Program {
     this.shouldExitProgram = shouldExitProgram;
     this.yargs.exitProcess(this.shouldExitProgram);
 
+    this.cleanupProcessEnvConfigs(systemProcess);
     const argv = this.getArguments();
 
     const cmd = argv._[0];
@@ -514,6 +544,13 @@ Example: $0 --help run.
         default: true,
         type: 'boolean',
       },
+      'watch-file': {
+        describe: 'Reload the extension only when the contents of this' +
+                  'file changes. This is useful if you use a custom' +
+                  ' build process for your extension',
+        demandOption: false,
+        type: 'string',
+      },
       'pre-install': {
         describe: 'Pre-install the extension into the profile before ' +
                   'startup. This is only needed to support older versions ' +
@@ -575,6 +612,12 @@ Example: $0 --help run.
         type: 'string',
         requiresArg: true,
       },
+      'adb-discovery-timeout': {
+        describe: 'Number of milliseconds to wait before giving up',
+        demandOption: false,
+        type: 'number',
+        requiresArg: true,
+      },
       'firefox-apk': {
         describe: (
           'Run a specific Firefox for Android APK. ' +
@@ -584,6 +627,13 @@ Example: $0 --help run.
         type: 'string',
         requiresArg: true,
       },
+      'firefox-apk-component': {
+        describe:
+          'Run a specific Android Component (defaults to <firefox-apk>/.App)',
+        demandOption: false,
+        type: 'string',
+        requiresArg: true,
+      },
     })
     .command('lint', 'Validate the extension source', commands.lint, {
       'output': {
