@@ -3,6 +3,7 @@ import path from 'path';
 
 import {fs} from 'mz';
 import parseJSON from 'parse-json';
+import stripBom from 'strip-bom';
 import stripJsonComments from 'strip-json-comments';
 
 import {InvalidManifest} from '../errors';
@@ -27,6 +28,7 @@ export type ExtensionManifest = {|
   version: string,
   default_locale?: string,
   applications?: ExtensionManifestApplications,
+  permissions?: Array<string>,
 |};
 
 export default async function getValidatedManifest(
@@ -44,13 +46,15 @@ export default async function getValidatedManifest(
       `Could not read manifest.json file at ${manifestFile}: ${error}`);
   }
 
+  manifestContents = stripBom(manifestContents);
+
   let manifestData;
 
   try {
-    manifestData = parseJSON(stripJsonComments(manifestContents), manifestFile);
+    manifestData = parseJSON(stripJsonComments(manifestContents));
   } catch (error) {
     throw new InvalidManifest(
-      `Error parsing manifest.json at ${manifestFile}: ${error}`);
+      `Error parsing manifest.json file at ${manifestFile}: ${error}`);
   }
 
   const errors = [];
